# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-24 15:44
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import django_simple_files.utils


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Files',
            fields=[
                ('file_id', models.AutoField(primary_key=True, serialize=False, verbose_name='ID')),
                ('file_uri', models.FileField(max_length=255, upload_to=django_simple_files.utils.get_upload_to, verbose_name='文件')),
                ('file_size', models.BigIntegerField(default=0, verbose_name='文件大小')),
                ('file_hash', models.CharField(max_length=32, verbose_name='文件hash')),
                ('time_created', models.DateTimeField(default=django.utils.timezone.now, verbose_name='上传时间')),
                ('uploader_uid', models.IntegerField(default=0, verbose_name='上传者UID')),
            ],
            options={
                'verbose_name_plural': '文件存档',
                'verbose_name': '文件存档',
                'ordering': ['-file_id'],
            },
        ),
        migrations.CreateModel(
            name='FilesRelated',
            fields=[
                ('related_id', models.AutoField(primary_key=True, serialize=False, verbose_name='ID')),
                ('file_uri', models.CharField(max_length=255, verbose_name='文件')),
                ('related_object_id', models.CharField(db_index=True, max_length=191, verbose_name='对象PK')),
                ('related_object', models.CharField(db_index=True, max_length=100, verbose_name='对象名')),
                ('time_created', models.DateTimeField(default=django.utils.timezone.now, verbose_name='上传时间')),
                ('file', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_simple_files.Files')),
            ],
            options={
                'verbose_name_plural': '文件关系存储',
                'verbose_name': '文件关系存储',
                'ordering': ['-related_id'],
            },
        ),
    ]



# -*- coding: UTF-8 -*-
import logging
import os

from django_simple_files import models, utils, storage

logger = logging.getLogger('django')


def save(name, content, uploader_uid=0, obj_id=0):
    """
    保存文件，同时保存文件至数据库
    :param obj_id:
    :param name:
    :param content:
    :param uploader_uid:
    :return:
    """

    file_name = name

    if utils.get_file_auto_hashname():
        name = utils.get_uuid_name(name)

    name = '%s_%s' % (uploader_uid, name)

    logger.debug(name)

    if obj_id > 0:
        file_db = models.Files.objects.get(pk=obj_id)
        name = file_db.file_uri.name
        if storage.exists(name):
            storage.delete(name)
        file_db.file_uri.name = storage.save(name, content)
    else:
        file_db = models.Files()
        file_db.uploader_uid = uploader_uid
        storage.save(name, content, file_db)

    file_db.file_name = file_name
    file_db.file_hash = utils.get_file_hash(content)
    file_db.file_size = len(content)

    file_db.save()
    return file_db


def save_by_uuid(file_name, content, uploader_uid=0):
    """
    随机生成文件名保存
    :param file_name:
    :param content:
    :param uploader_uid:
    :return:
    """
    hash_name = utils.hash_uuid()
    file_ext = os.path.splitext(file_name)[-1]
    return save(hash_name + file_ext, content, uploader_uid)


def save_related(file_db, related_object):
    """
    保存关系表
    :param file_db:
    :param related_object:
    :return:
    """
    file_related = models.FilesRelated()
    file_related.file = file_db
    file_related.file_uri = file_db.file_uri
    file_related.related_object_id = related_object.pk
    file_related.related_object = utils.get_object_name(related_object)
    file_related.save()
    return file_related


def get_related_by_object(related_object, page=1, page_size=20):
    """
    根据对象名与对象pk返回相关数据
    :param related_object:
    :param page:
    :param page_size:
    :return:
    """
    return _file_related_filter_by_object(related_object)[(page - 1) * page_size:page_size]


def get_related(related_object, page=1, page_size=20):
    """
    根据对象名返回相关数据
    :param related_object:
    :param page:
    :param page_size:
    :return:
    """
    return _file_related_filter(utils.get_object_name(related_object))[(page - 1) * page_size:page_size]


def delete_related_by_object(related_object):
    _file_related_filter(related_object).delete()


def _file_related_filter_by_object(related_object, file_id=0):
    related_object_name = utils.get_object_name(related_object)
    related_object_id = related_object.pk if hasattr(related_object, 'pk') else None
    return _file_related_filter(related_object_name, related_object_id, file_id)


def _file_related_filter(related_object_name, related_object_id=None, file_id=0):
    query = {'related_object': related_object_name}
    if related_object_id:
        query['related_object_id'] = related_object_id
    if file_id:
        query['file_id'] = file_id
    return models.FilesRelated.objects.filter(**query)



# -*- coding: UTF-8 -*-
import os

from django.conf import settings

SIMPLE_FILES = {
    'FILE_HASH_FUN': 'MD5',
    'FILE_UPLOAD_TO': 'upload/%Y%m%d',
    'FILE_LOCAL_BACKUP': False,
    'FILE_LOCAL_BACKUP_DIR': os.path.join(settings.BASE_DIR, 'storage/backup'),
    'FILE_AUTO_HASHNAME': True
}



# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-11-05 00:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_simple_files', '0002_files_enabled'),
    ]

    operations = [
        migrations.AddField(
            model_name='files',
            name='file_name',
            field=models.CharField(default='file', max_length=255, verbose_name='文件名'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='files',
            name='file_hash',
            field=models.CharField(max_length=40, verbose_name='文件hash'),
        ),
        migrations.AlterField(
            model_name='files',
            name='file_uri',
            field=models.FileField(max_length=255, upload_to='upload/%Y%m%d', verbose_name='文件'),
        ),
    ]
